# Import functions
. "$PSScriptRoot\functions\console.ps1"
. "$PSScriptRoot\functions\header.ps1"

# Initialize
Write-Header

Get-Info

Write-Separator


# get all json files
$jsonFiles = Get-ChildItem -Recurse -Filter "*.json" -Exclude "*.schema.*" | select -ExpandProperty FullName
$jsonSchemaFiles = Get-ChildItem -Recurse -Filter "*.schema.json" | select -ExpandProperty FullName

# find schema that matches location and name of file
$errors = $False

$jsonFiles | Foreach-Object {
    $json = $_
    $jsonWithoutSchema = $json -replace "schema.", ""
    $schema = $jsonSchemaFiles | Where-Object {$($_ -replace "schema.", "") -eq $jsonWithoutSchema}
    
    if($schema) {
        $jsonContent = Get-Content $json | ConvertFrom-Json  -Depth 100 | ConvertTo-Json  -Depth 100
        $result = $False
        Write-Separator

        Write-Host "Processing File: $(Remove-Current-Location -location $json)" 
        Write-Host "         Schema: $(Remove-Current-Location -location $schema)" 

        # validate schema
        $result = Test-Json -Json $jsonContent -SchemaFile $schema -ErrorAction SilentlyContinue -ErrorVariable err

        Write-Host "          Valid: $result" 
       
        if(!$result) {
            Write-Host "          Error: $err" 
            $errors = $True
        }
    }
}

if($errors) {
    exit 1
}

Write-Separator

Write-OutputCenter("And as always, have a nice day!")

Write-Separator
